@@ -630,6 +630,7 @@ void setcolorscheme(Boolean boolvalue)
    colorlist[RATSNESTCOLOR].color.pixel = appdata.ratsnestcolor;
    colorlist[BBOXCOLOR].color.pixel = appdata.bboxpix;
    colorlist[CLIPMASKCOLOR].color.pixel = appdata.clipcolor;
+   colorlist[FIXEDBBOXCOLOR].color.pixel = appdata.fixedbboxpix;
 
    /* Fill in pixel information */
 
@@ -839,8 +840,8 @@ void renamepage(short pagenumber)
    if ((pagenumber >= 0) && (pagenumber < xobjs.pages - 1) &&
 	    (thisinst != NULL)) {
       plabel = thisinst->thisobject->name;
-      pname = (char *)malloc(28 + strlen(plabel));
-      sprintf(pname, "xcircuit::renamepage %d {%s}", pagenumber + 1, plabel);
+      pname = (char *)malloc(36 + strlen(plabel));
+      sprintf(pname, "catch {xcircuit::renamepage %d {%s}}", pagenumber + 1, plabel);
       Tcl_Eval(xcinterp, pname);
       free(pname);
    }
@@ -1100,7 +1101,7 @@ void setcolor(xcWidget w, int cindex)
 			areawin->topinstance);
       nextptr = findstringpart(areawin->textpos, NULL, curlabel->string,
 			areawin->topinstance);
-      if (strptr->type == FONT_COLOR) {
+      if (strptr && strptr->type == FONT_COLOR) {
 	 undrawtext(curlabel);
 	 strptr->data.color = cindex;
 	 redrawtext(curlabel);
@@ -1151,7 +1152,7 @@ void togglefontmark(int fontval)
 
 /*------------------------------------------------------*/
 /* Set checkmarks on label style menu 			*/
-/* fvalue is for font, jvalue is for justification	*/
+/* fvalue is for font, jvalue is for anchoring		*/
 /*------------------------------------------------------*/
 
 void togglestylemark(int styleval)
@@ -1173,19 +1174,22 @@ void toggleencodingmark(int encodingval)
 }
 
 /*------------------------------------------------------*/
-/* Set checkmarks on label justification & flags menu	*/
+/* Set checkmarks on label anchoring & flags menu	*/
 /*------------------------------------------------------*/
 
-void togglejustmarks(int justvalue)
+void toggleanchormarks(int anchorvalue)
 {
-   XcInternalTagCall(xcinterp, 4, "label", "justify", (justvalue & RIGHT) ? "right" :
-	(justvalue & NOTLEFT) ? "center" : "left",
-	(justvalue & TOP) ? "top" : (justvalue & NOTBOTTOM) ? "middle" : "bottom");
-   XcInternalTagCall(xcinterp, 3, "label", "flipinvariant", (justvalue & FLIPINV) ?
+   XcInternalTagCall(xcinterp, 4, "label", "anchor", (anchorvalue & RIGHT) ? "right" :
+	(anchorvalue & NOTLEFT) ? "center" : "left",
+	(anchorvalue & TOP) ? "top" : (anchorvalue & NOTBOTTOM) ? "middle" : "bottom");
+   XcInternalTagCall(xcinterp, 3, "label", "justify", (anchorvalue & JUSTIFYRIGHT) ?
+	"right" : (anchorvalue & TEXTCENTERED) ? "center" : (anchorvalue & JUSTIFYBOTH)
+	? "both" : "left");
+   XcInternalTagCall(xcinterp, 3, "label", "flipinvariant", (anchorvalue & FLIPINV) ?
 	"true" : "false");
-   XcInternalTagCall(xcinterp, 3, "label", "latex", (justvalue & LATEXLABEL) ?
+   XcInternalTagCall(xcinterp, 3, "label", "latex", (anchorvalue & LATEXLABEL) ?
 	"true" : "false");
-   XcInternalTagCall(xcinterp, 3, "label", "visible", (justvalue & PINVISIBLE) ?
+   XcInternalTagCall(xcinterp, 3, "label", "visible", (anchorvalue & PINVISIBLE) ?
 	"true" : "false");
 }
 
@@ -1200,7 +1204,7 @@ void setfontmarks(short fvalue, short jvalue)
       togglestylemark(fvalue);
       togglefontmark(fvalue);
    }
-   togglejustmarks(jvalue);
+   toggleanchormarks(jvalue);
 }
 
 #endif /* TCL_WRAPPER */
@@ -1256,7 +1260,7 @@ void startunparam(xcWidget w, pointertype value, caddr_t calldata)
 
 void setdefaultfontmarks()
 {
-   setfontmarks(areawin->psfont, areawin->justify);
+   setfontmarks(areawin->psfont, areawin->anchor);
 }
 
 /*----------------------------------------------------------------*/
@@ -1282,6 +1286,7 @@ short findbestfont(short curfont, short newfont, short style, short encoding) {
    short i, newstyle, newenc;
 
    if (fontcount == 0) return -1;
+   if (curfont < 0) curfont = 0;
 
    if (newfont < 0)
       newfamily = fonts[curfont].family;
@@ -1687,7 +1692,7 @@ Boolean dospecial()
    int cfont;
 
    curlabel = TOLABEL(EDITPART);
-   if (curlabel->justify & LATEXLABEL) return False;
+   if (curlabel->anchor & LATEXLABEL) return False;
 
    cfont = findcurfont(areawin->textpos, curlabel->string, areawin->topinstance);
    composefontlib(cfont);
