@@ -120,7 +120,7 @@ short	 popups;      /* total number of popup widgets on the screen */
 /*----------------------------------------------------------------------*/
 
 extern aliasptr aliastop;
-extern float version;
+extern char version[];
 
 #ifdef TCL_WRAPPER
 extern Tcl_Interp *xcinterp;
@@ -156,7 +156,13 @@ void addtocolorlist(xcWidget button, int cvalue)
 
    /* Get and store the RGB values of the new color */
    
-   XQueryColors(dpy, cmap, &(colorlist[number_colors - 1].color), 1);
+   if (areawin->area == NULL) {
+      colorlist[number_colors - 1].color.red = 256 * (cvalue & 0xff);
+      colorlist[number_colors - 1].color.green = 256 * ((cvalue >> 8) & 0xff);
+      colorlist[number_colors - 1].color.blue = 256 * ((cvalue >> 16) & 0xff);
+   }
+   else
+      XQueryColors(dpy, cmap, &(colorlist[number_colors - 1].color), 1);
 }
 
 /*----------------------------------------------------------------------*/
@@ -389,8 +395,12 @@ int quitcheck(xcWidget w, caddr_t clientdata, caddr_t calldata)
    }
    else {
       free(promptstr);
-      quit(w, NULL);
-      return 1;
+      quit(w, NULL);				// preparation for quit
+      if (calldata != (caddr_t)NULL)
+         Tcl_Eval(xcinterp, "quitnocheck intr");
+      else
+         Tcl_Eval(xcinterp, "quitnocheck");	// actual quit
+      return 1;					// not reached
    }
 }
 
@@ -402,7 +412,7 @@ int quitcheck(xcWidget w, caddr_t clientdata, caddr_t calldata)
 
 void dointr(int signum)
 {
-   quitcheck(NULL, NULL, NULL);
+   quitcheck(NULL, NULL, (caddr_t)1);
 }
 
 /*--------------*/
@@ -714,7 +724,13 @@ void xc_get_color_rgb(unsigned long cidx, unsigned short *red,
          .pixel = cidx,
          .flags = DoRed | DoGreen | DoBlue
    };
-   XQueryColors(dpy, cmap, &loccolor, 1);
+   if (areawin->area == NULL) {
+      loccolor.red = cidx & 0xff;
+      loccolor.green = (cidx >> 8) & 0xff;
+      loccolor.blue = (cidx >> 16) & 0xff;
+   }
+   else
+      XQueryColors(dpy, cmap, &loccolor, 1);
    *red = loccolor.red;
    *green = loccolor.green;
    *blue = loccolor.blue;
@@ -783,8 +799,121 @@ int xc_alloccolor(char *name)
    fromC.size = strlen(name);
    fromC.addr = name;
 
-   CvtStringToPixel(NULL, &zval, &fromC, &toC);
-   pixval = (int)(*((u_long *)toC.addr));
+   if (areawin->area) {
+      CvtStringToPixel(NULL, &zval, &fromC, &toC);
+      pixval = (int)(*((u_long *)toC.addr));
+   }
+   else {
+      int r, g, b;
+
+      /* Graphics-free batch mode.  Handle basic colors plus RGB */
+      if (name[0] == '#' && (strlen(name) == 7)) {
+         sscanf(&name[1], "%2x", &r);
+         sscanf(&name[3], "%2x", &g);
+         sscanf(&name[5], "%2x", &b);
+         pixval = r + g * 256 + b * 65536;
+      }
+      else if (name[0] == '#' && (strlen(name) == 13)) {
+         sscanf(&name[1], "%4x", &r);
+         sscanf(&name[5], "%4x", &g);
+         sscanf(&name[9], "%4x", &b);
+         pixval = (r >> 8) + (g >> 8) * 256 + (b >> 8) * 65536;
+      }
+      else if (sscanf(name, "%d", &pixval) != 1) {
+	 if (!strcasecmp(name, "red")) {
+	    r = 255;
+	    g = 0;
+	    b = 0;
+	 }
+	 else if (!strcasecmp(name, "green")) {
+	    r = 0;
+	    g = 255;
+	    b = 0;
+	 }
+	 else if (!strcasecmp(name, "blue")) {
+	    r = 0;
+	    g = 0;
+	    b = 255;
+	 }
+	 else if (!strcasecmp(name, "white")) {
+	    r = 255;
+	    g = 255;
+	    b = 255;
+	 }
+	 else if (!strcasecmp(name, "gray")) {
+	    r = 128;
+	    g = 128;
+	    b = 128;
+	 }
+	 else if (!strcasecmp(name, "yellow")) {
+	    r = 255;
+	    g = 255;
+	    b = 0;
+	 }
+	 else if (!strcasecmp(name, "gray40")) {
+	    r = 102;
+	    g = 102;
+	    b = 102;
+	 }
+	 else if (!strcasecmp(name, "gray60")) {
+	    r = 153;
+	    g = 153;
+	    b = 153;
+	 }
+	 else if (!strcasecmp(name, "gray80")) {
+	    r = 204;
+	    g = 204;
+	    b = 204;
+	 }
+	 else if (!strcasecmp(name, "gray90")) {
+	    r = 229;
+	    g = 229;
+	    b = 229;
+	 }
+	 else if (!strcasecmp(name, "green2")) {
+	    r = 0;
+	    g = 238;
+	    b = 0;
+	 }
+	 else if (!strcasecmp(name, "purple")) {
+	    r = 160;
+	    g = 32;
+	    b = 240;
+	 }
+	 else if (!strcasecmp(name, "steelblue2")) {
+	    r = 92;
+	    g = 172;
+	    b = 238;
+	 }
+	 else if (!strcasecmp(name, "red3")) {
+	    r = 205;
+	    g = 0;
+	    b = 0;
+	 }
+	 else if (!strcasecmp(name, "tan")) {
+	    r = 210;
+	    g = 180;
+	    b = 140;
+	 }
+	 else if (!strcasecmp(name, "brown")) {
+	    r = 165;
+	    g = 42;
+	    b = 42;
+	 }
+	 else if (!strcasecmp(name, "pink")) {
+	    r = 255;
+	    g = 192;
+	    b = 203;
+	 }
+         else {
+	    // Default to black
+	    r = 0;
+	    g = 0;
+	    b = 0;
+	 }
+         pixval = r + g * 256 + b * 65536;
+      }
+   }
 
    return pixval;
 }
@@ -855,10 +984,16 @@ int rgb_alloccolor(int red, int green, int blue)
       newcolor.green = green;
       newcolor.blue = blue;
       newcolor.flags = DoRed | DoGreen | DoBlue;
-      if (XAllocColor(dpy, cmap, &newcolor) == 0)
-         pixval = findnearcolor(&newcolor);
-      else
-	 pixval = newcolor.pixel;
+      if (areawin->area) {
+         if (XAllocColor(dpy, cmap, &newcolor) == 0)
+            pixval = findnearcolor(&newcolor);
+         else
+	    pixval = newcolor.pixel;
+      }
+      else {
+	 // No graphics mode:  Force pixel to be 24 bit RGB
+	 pixval = (red & 0xff) | ((blue & 0xff) << 8) | ((green & 0xff) << 16);
+      }
 
       // Add this to the colormap
       tableidx = addnewcolorentry(pixval);
@@ -878,9 +1013,11 @@ int rgb_alloccolor(int red, int green, int blue)
 int query_named_color(char *cname)
 {
    XColor cvcolor, cvexact;
-   int tableidx, result;
+   int tableidx, result = 0;
 
-   result = XLookupColor(dpy, cmap, cname, &cvexact, &cvcolor);
+   if (areawin->area)
+      result = XLookupColor(dpy, cmap, cname, &cvexact, &cvcolor);
+     
    if (result == 0) return BADCOLOR;
 
    tableidx = rgb_querycolor(cvcolor.red, cvcolor.green, cvcolor.blue, NULL);
@@ -899,6 +1036,8 @@ void makecursors()
    Tk_Uid fg_uid, bg_uid;
 #endif
 
+   if (areawin->area == NULL) return;
+
    bgcolor.pixel = colorlist[BACKGROUND].color.pixel;
    fgcolor.pixel = colorlist[FOREGROUND].color.pixel;
    XQueryColors(dpy, cmap, &fgcolor, 1);
@@ -1146,7 +1285,7 @@ void pre_initialize()
    /* initialize user variables */
    /*---------------------------*/
 
-   version = PROG_VERSION;
+   strcpy(version, PROG_VERSION);
    aliastop = NULL;
    xobjs.pagelist = (Pagedata **) malloc(PAGES * sizeof(Pagedata *));
    for (page = 0; page < PAGES; page++) {
@@ -1478,7 +1617,7 @@ void post_initialize()
    /* middle of the viewing window.					 */
 
 #if !defined(HAVE_CAIRO)
-   if (dbuf == (Pixmap)NULL)
+   if ((dbuf == (Pixmap)NULL) && areawin->area)
       dbuf = XCreatePixmap(dpy, areawin->window, areawin->width,
 		areawin->height, DefaultDepthOfScreen(xcScreen(areawin->area)));
 #endif
@@ -1497,17 +1636,21 @@ void post_initialize()
 
    /*-----------------------------------------------------*/
    /* Set the cursor as a crosshair for the area widget.  */
+   /* If areawin->area is NULL, then xcircuit is running  */
+   /* in batch mode, and no automatic save will be done.  */
    /*-----------------------------------------------------*/
 
-   XDefineCursor (dpy, areawin->window, DEFAULTCURSOR);
+   if (areawin->area != NULL) {
+      XDefineCursor (dpy, areawin->window, DEFAULTCURSOR);
 
-   /*---------------------------------------------------*/
-   /* Set up a timeout for automatic save to a tempfile */
-   /*---------------------------------------------------*/
+      /*---------------------------------------------------*/
+      /* Set up a timeout for automatic save to a tempfile */
+      /*---------------------------------------------------*/
 
-   xobjs.save_interval = appdata.timeout;
-   xobjs.timeout_id = xcAddTimeOut(app, 60000 * xobjs.save_interval,
-	savetemp, NULL);
+      xobjs.save_interval = appdata.timeout;
+      xobjs.timeout_id = xcAddTimeOut(app, 60000 * xobjs.save_interval,
+		savetemp, NULL);
+   }
 }
 
 /*----------------------------------------------------------------------*/
