@@ -499,6 +499,7 @@ enum loadmodes {IMPORT = 1, PSBKGROUND, SCRIPT, RECOVER,
 #define BBOX 512
 #define SQUARECAP 1024
 #define CLIPMASK  2048
+#define FIXEDBBOX 4096
 
 /*----------------------------------------------------------------------*/
 /* Box edit styles							*/
@@ -1202,7 +1203,7 @@ typedef struct {
    Pixel	globalcolor, localcolor, infocolor, ratsnestcolor;
 
    /* non-schematic layout color(s) */
-   Pixel	bboxpix, clipcolor;
+   Pixel	fixedbboxpix, bboxpix, clipcolor;
 
    /* color scheme 1 */
    Pixel	fg, bg;
@@ -1256,7 +1257,7 @@ typedef struct {
 /* 	    4	 <reserved, possibly for LaTeX font type>		*/
 /*	    5    special encoding = 1, Standard Encoding = 0		*/
 /*	    6	 ISOLatin1 = 2, ISOLatin2 = 3				*/
-/*	    7    <reserved for other encoding schemes>			*/
+/*	    7+   <reserved for other encoding schemes>			*/
 /*----------------------------------------------------------------------*/
 
 typedef struct {
